@@ -1,21 +1,11 @@
 function _aws_cdk_aws_lambda_python_PythonFunction(p) {
 }
-function _aws_cdk_aws_lambda_python_PythonLayerVersionProps(p) {
-    if (p == null)
-        return;
-    visitedObjects.add(p);
-    if (!visitedObjects.has(p.compatibleArchitectures))
-        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_Architecture(p.compatibleArchitectures);
-    if (!visitedObjects.has(p.compatibleRuntimes))
-        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_Runtime(p.compatibleRuntimes);
-    visitedObjects.delete(p);
-}
-function _aws_cdk_aws_lambda_python_PythonLayerVersion(p) {
-}
 function _aws_cdk_aws_lambda_python_PythonFunctionProps(p) {
     if (p == null)
         return;
     visitedObjects.add(p);
+    if (!visitedObjects.has(p.bundling))
+        _aws_cdk_aws_lambda_python_BundlingOptions(p.bundling);
     if ("architectures" in p)
         print("@aws-cdk/aws-lambda.FunctionOptions#architectures", "use `architecture`");
     if (!visitedObjects.has(p.architectures))
@@ -32,6 +22,22 @@ function _aws_cdk_aws_lambda_python_PythonFunctionProps(p) {
         require("@aws-cdk/aws-ec2/.warnings.jsii.js")._aws_cdk_aws_ec2_ISecurityGroup(p.securityGroups);
     visitedObjects.delete(p);
 }
+function _aws_cdk_aws_lambda_python_PythonLayerVersion(p) {
+}
+function _aws_cdk_aws_lambda_python_PythonLayerVersionProps(p) {
+    if (p == null)
+        return;
+    visitedObjects.add(p);
+    if (!visitedObjects.has(p.bundling))
+        _aws_cdk_aws_lambda_python_BundlingOptions(p.bundling);
+    if (!visitedObjects.has(p.compatibleArchitectures))
+        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_Architecture(p.compatibleArchitectures);
+    if (!visitedObjects.has(p.compatibleRuntimes))
+        require("@aws-cdk/aws-lambda/.warnings.jsii.js")._aws_cdk_aws_lambda_Runtime(p.compatibleRuntimes);
+    visitedObjects.delete(p);
+}
+function _aws_cdk_aws_lambda_python_BundlingOptions(p) {
+}
 function print(name, deprecationMessage) {
     const deprecated = process.env.JSII_DEPRECATED;
     const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
@@ -47,5 +53,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_lambda_python_PythonFunction, _aws_cdk_aws_lambda_python_PythonLayerVersionProps, _aws_cdk_aws_lambda_python_PythonLayerVersion, _aws_cdk_aws_lambda_python_PythonFunctionProps };
+module.exports = { print, _aws_cdk_aws_lambda_python_PythonFunction, _aws_cdk_aws_lambda_python_PythonFunctionProps, _aws_cdk_aws_lambda_python_PythonLayerVersion, _aws_cdk_aws_lambda_python_PythonLayerVersionProps, _aws_cdk_aws_lambda_python_BundlingOptions };
 module.exports.DeprecationError = DeprecationError;
